=========
monprojet
=========

Un projet de démo

FIXME: provide a two paragraphs summary of this package

Full documentation and API
==========================

FIXME: Provide the URL of the documentation (@ readthedocs.org ?)

Developer notes
===============

Please use a virtualenv to maintain this package, but I should not need to say that.

Grab the source from the SCM repository:

.. code:: console

  $ python setup.py develop
  $ pip install monprojet[dev]

Run the tests:

.. code:: console

  $ python setup.py test
  $ python run_tests.py


Links
=====

FIXME: Provide real links

Project home page

  http://www.mystuff.com/project

Source code

  http://www.mystuff.com/source

Issues tracker

  http://www.mystuff.com/issues
